@@ -300,6 +300,16 @@ Init_milter_client_context (void)
 
     G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "connect",
 		      rb_milter__connect_signal_convert);
+    G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "helo",
+                      rb_milter__helo_signal_convert);
+    G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "envelope-from",
+                      rb_milter__envelope_from_signal_convert);
+    G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "envelope-recipient",
+                      rb_milter__envelope_recipient_signal_convert);
+    G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "unknown",
+                      rb_milter__unknown_signal_convert);
+    G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "header",
+                      rb_milter__header_signal_convert);
     G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "body",
 		      rb_milter__body_signal_convert);
     G_DEF_SIGNAL_FUNC(rb_cMilterClientContext, "end-of-message",
