@@ -36,7 +36,6 @@ have_func("g_listenv", glib_header)
 
 ruby_header = "ruby.h"
 have_func("rb_check_array_type", ruby_header)
-have_func("rb_check_hash_type", ruby_header)
 have_func("rb_exec_recursive", ruby_header)
 have_func("rb_errinfo", ruby_header)
 have_func("rb_sourcefile", ruby_header)
@@ -58,7 +57,7 @@ include_paths = PKGConfig.cflags_only_I("glib-2.0")
 headers = include_paths.split.inject([]) do |result, path|
   result + Dir.glob(File.join(path.sub(/^-I/, ""), "glib", "*.h"))
 end.reject do |file|
-  /g(iochannel|main|scanner)\.h/ =~ file
+  /g(iochannel|scanner)\.h/ =~ file
 end
 include_paths = PKGConfig.cflags_only_I("gobject-2.0")
 headers = include_paths.split.inject(headers) do |result, path|
