@@ -14,6 +14,11 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+begin
+  require "pkg-config/version"
+rescue LoadError
+end
+
 require "rbconfig"
 
 require 'mkmf'
@@ -316,8 +321,6 @@ class PackageConfig
 end
 
 module PKGConfig
-  VERSION = "1.1.3"
-
   @@paths = []
   @@override_variables = {}
 
@@ -331,7 +334,7 @@ module PKGConfig
   end
 
   def msvc?
-    /mswin32/.match(RUBY_PLATFORM) and /^cl\b/.match(RbConfig::CONFIG['CC'])
+    /mswin/.match(RUBY_PLATFORM) and /^cl\b/.match(RbConfig::CONFIG['CC'])
   end
 
   def package_config(package)
@@ -404,7 +407,7 @@ module PKGConfig
                   Shellwords.shellwords(libraries))
       dldflags = dldflags.map {|s| /\s/ =~ s ? "\"#{s}\"" : s }.join(' ')
       $libs   += ' ' + libraries
-      if /mswin32/ =~ RUBY_PLATFORM
+      if /mswin/ =~ RUBY_PLATFORM
         $DLDFLAGS += ' ' + dldflags
       else
         $LDFLAGS += ' ' + dldflags
