@@ -84,7 +84,7 @@ module Milter
 
       [:negotiate, :connect, :helo, :envelope_from, :envelope_recipient,
        :data, :unknown, :header, :end_of_header, :body, :end_of_message,
-       :abort, :finished].each do |event|
+       :finished].each do |event|
         next unless session.respond_to?(event)
         context.signal_connect(event) do |_context, *args|
           begin
@@ -102,6 +102,26 @@ module Milter
           status
         end
       end
+
+      context.signal_connect(:abort) do |_context, *args|
+        if session.respond_to?(:abort)
+          begin
+            session.abort(*args)
+          rescue Exception
+            Milter::Logger.error($!)
+            session_context.status = fallback_status
+          end
+        end
+        begin
+          session.reset
+        rescue Exception
+          Milter::Logger.error($!)
+          session_context.status = fallback_status
+        end
+        status = session_context.status
+        session_context.clear
+        status
+      end
     end
 
     def reload_callbacks
@@ -112,6 +132,7 @@ module Milter
   class ClientSession
     def initialize(context)
       @context = context
+      reset
     end
 
     def negotiate(option, macros_requests)
@@ -130,6 +151,9 @@ module Milter
       continue
     end
 
+    def reset
+    end
+
     private
     def need_header_value_with_leading_space?
       false
@@ -137,10 +161,12 @@ module Milter
 
     def accept
       @context.status = :accept
+      reset
     end
 
     def discard
       @context.status = :discard
+      reset
     end
 
     def continue
@@ -168,6 +194,7 @@ module Milter
       else
         @context.status = :reject
       end
+      reset
     end
 
     def temporary_failure(options={})
@@ -183,6 +210,7 @@ module Milter
       else
         @context.status = :temporary_failure
       end
+      reset
     end
 
     def quarantine(reason)
