@@ -142,10 +142,18 @@ extern void _milter_marshal_VOID__OBJECT_OBJECT_ENUM (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* VOID:ENUM (./milter-marshalers.list:18) */
+/* VOID:OBJECT,OBJECT,OBJECT (./milter-marshalers.list:18) */
+extern void _milter_marshal_VOID__OBJECT_OBJECT_OBJECT (GClosure     *closure,
+                                                        GValue       *return_value,
+                                                        guint         n_param_values,
+                                                        const GValue *param_values,
+                                                        gpointer      invocation_hint,
+                                                        gpointer      marshal_data);
+
+/* VOID:ENUM (./milter-marshalers.list:19) */
 #define _milter_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* BOOLEAN:VOID (./milter-marshalers.list:19) */
+/* BOOLEAN:VOID (./milter-marshalers.list:20) */
 extern void _milter_marshal_BOOLEAN__VOID (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -153,7 +161,7 @@ extern void _milter_marshal_BOOLEAN__VOID (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* BOOLEAN:POINTER (./milter-marshalers.list:20) */
+/* BOOLEAN:POINTER (./milter-marshalers.list:21) */
 extern void _milter_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -161,7 +169,7 @@ extern void _milter_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* BOOLEAN:STRING (./milter-marshalers.list:21) */
+/* BOOLEAN:STRING (./milter-marshalers.list:22) */
 extern void _milter_marshal_BOOLEAN__STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -169,7 +177,7 @@ extern void _milter_marshal_BOOLEAN__STRING (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* BOOLEAN:STRING,STRING (./milter-marshalers.list:22) */
+/* BOOLEAN:STRING,STRING (./milter-marshalers.list:23) */
 extern void _milter_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -177,7 +185,7 @@ extern void _milter_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
 
-/* BOOLEAN:STRING,UINT (./milter-marshalers.list:23) */
+/* BOOLEAN:STRING,UINT (./milter-marshalers.list:24) */
 extern void _milter_marshal_BOOLEAN__STRING_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -185,7 +193,7 @@ extern void _milter_marshal_BOOLEAN__STRING_UINT (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* BOOLEAN:STRING,UINT64 (./milter-marshalers.list:24) */
+/* BOOLEAN:STRING,UINT64 (./milter-marshalers.list:25) */
 extern void _milter_marshal_BOOLEAN__STRING_UINT64 (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -193,7 +201,7 @@ extern void _milter_marshal_BOOLEAN__STRING_UINT64 (GClosure     *closure,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
 
-/* BOOLEAN:STRING,POINTER,UINT (./milter-marshalers.list:25) */
+/* BOOLEAN:STRING,POINTER,UINT (./milter-marshalers.list:26) */
 extern void _milter_marshal_BOOLEAN__STRING_POINTER_UINT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -201,7 +209,7 @@ extern void _milter_marshal_BOOLEAN__STRING_POINTER_UINT (GClosure     *closure,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);
 
-/* ENUM:STRING,POINTER,UINT (./milter-marshalers.list:26) */
+/* ENUM:STRING,POINTER,UINT (./milter-marshalers.list:27) */
 extern void _milter_marshal_ENUM__STRING_POINTER_UINT (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
@@ -209,7 +217,7 @@ extern void _milter_marshal_ENUM__STRING_POINTER_UINT (GClosure     *closure,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);
 
-/* ENUM:OBJECT,OBJECT (./milter-marshalers.list:27) */
+/* ENUM:OBJECT,OBJECT (./milter-marshalers.list:28) */
 extern void _milter_marshal_ENUM__OBJECT_OBJECT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -217,7 +225,7 @@ extern void _milter_marshal_ENUM__OBJECT_OBJECT (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* ENUM:STRING (./milter-marshalers.list:28) */
+/* ENUM:STRING (./milter-marshalers.list:29) */
 extern void _milter_marshal_ENUM__STRING (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -225,7 +233,7 @@ extern void _milter_marshal_ENUM__STRING (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* ENUM:STRING,STRING (./milter-marshalers.list:29) */
+/* ENUM:STRING,STRING (./milter-marshalers.list:30) */
 extern void _milter_marshal_ENUM__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -233,7 +241,7 @@ extern void _milter_marshal_ENUM__STRING_STRING (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* ENUM:VOID (./milter-marshalers.list:30) */
+/* ENUM:VOID (./milter-marshalers.list:31) */
 extern void _milter_marshal_ENUM__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -241,7 +249,7 @@ extern void _milter_marshal_ENUM__VOID (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* ENUM:ENUM (./milter-marshalers.list:31) */
+/* ENUM:ENUM (./milter-marshalers.list:32) */
 extern void _milter_marshal_ENUM__ENUM (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -249,7 +257,7 @@ extern void _milter_marshal_ENUM__ENUM (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* ENUM:STRING,UINT (./milter-marshalers.list:32) */
+/* ENUM:STRING,UINT (./milter-marshalers.list:33) */
 extern void _milter_marshal_ENUM__STRING_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -257,7 +265,7 @@ extern void _milter_marshal_ENUM__STRING_UINT (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* ENUM:STRING,UINT64 (./milter-marshalers.list:33) */
+/* ENUM:STRING,UINT64 (./milter-marshalers.list:34) */
 extern void _milter_marshal_ENUM__STRING_UINT64 (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
