@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -56,7 +56,8 @@ MilterManager        *milter_manager_new         (MilterManagerConfiguration *co
 MilterManagerConfiguration *milter_manager_get_configuration (MilterManager *manager);
 const GList          *milter_manager_get_leaders (MilterManager *manager);
 
-gboolean              milter_manager_reload      (MilterManager *manager);
+gboolean              milter_manager_reload      (MilterManager *manager,
+                                                  GError       **error);
 void                  milter_manager_set_launcher_channel
                                                  (MilterManager *manager,
                                                   GIOChannel *read_channel,
