@@ -147,6 +147,8 @@ feed (const gchar *packet, gsize packet_size)
     milter_client_context_feed(context, packet, packet_size, &error);
     gcut_assert_error(error_in_callback);
 
+    if (MILTER_IS_LIBEV_EVENT_LOOP(loop))
+        cut_omit("MilterLibevEventLoop doesn't support GCutStringIOChannel.");
     milter_test_pump_all_events(loop);
 
     return error;
