@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2012  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,7 +43,7 @@ static GPrintFunc original_print_hander;
 static void
 setup_syslog (void)
 {
-    struct stat buf;
+    struct stat status;
     gint i;
     gchar *candidates[] = {
         "/var/log/mail.log",
@@ -63,8 +63,8 @@ setup_syslog (void)
                     cut_take_string(g_strjoinv(", ", candidates)));
     cut_assert_not_null(syslog_file_name);
 
-    cut_assert_equal_int(0, g_lstat(syslog_file_name, &buf));
-    first_log_file_size = buf.st_size;
+    cut_assert_equal_int(0, g_lstat(syslog_file_name, &status));
+    first_log_file_size = status.st_size;
 }
 
 void
@@ -113,6 +113,21 @@ collect_log_message (void)
     g_io_channel_seek_position(syslog, first_log_file_size, G_SEEK_SET, &error);
     gcut_assert_error(error);
 
+    {
+        glong waited_micro_seconds = 0;
+        glong max_wait_micro_seconds = 1 * G_USEC_PER_SEC;
+        while (waited_micro_seconds < max_wait_micro_seconds) {
+            glong wait_micro_seconds = G_USEC_PER_SEC * 0.1;
+            struct stat status;
+            cut_assert_equal_int(0, g_lstat(syslog_file_name, &status));
+            if (status.st_size > first_log_file_size) {
+                break;
+            }
+            g_usleep(wait_micro_seconds);
+            waited_micro_seconds += wait_micro_seconds;
+        }
+    }
+
     g_io_channel_read_to_end(syslog, &actual, &read_length, &error);
     gcut_assert_error(error);
 }
