@@ -445,6 +445,16 @@ data_flags_from_string_success (void)
         MILTER_LOG_LEVEL_CRITICAL |
         MILTER_LOG_LEVEL_WARNING |
         MILTER_LOG_LEVEL_ERROR);
+    ADD("local append",
+        MILTER_LOG_LEVEL_CRITICAL | MILTER_LOG_LEVEL_DEBUG,
+        "-warning|error|+debug",
+        MILTER_LOG_LEVEL_CRITICAL |
+        MILTER_LOG_LEVEL_WARNING |
+        MILTER_LOG_LEVEL_ERROR);
+    ADD("local remove",
+        (MILTER_LOG_LEVEL_ALL | MILTER_LOG_LEVEL_NONE) & ~MILTER_LOG_LEVEL_TRACE,
+        "all|-trace",
+        0);
 
 #undef ADD
 }
@@ -600,9 +610,9 @@ data_flags_names (void)
     ADD("multi", MILTER_LOG_LEVEL_CRITICAL | MILTER_LOG_LEVEL_INFO,
         "critical|info");
     ADD("all", MILTER_LOG_LEVEL_ALL,
-        "critical|error|warning|message|info|debug|statistics|profile");
+        "critical|error|warning|message|info|debug|trace|statistics|profile");
     ADD("unknown", MILTER_LOG_LEVEL_PROFILE << 1,
-        "(unknown flags: MilterLogLevelFlags:0x200)");
+        "(unknown flags: MilterLogLevelFlags:0x400)");
 
 #undef ADD
 }
